@@ -27,7 +27,7 @@ class syntax_plugin_fckg_indent extends DokuWiki_Syntax_Plugin {
             'email'  => 'turnermm02@shaw.ca',
             'date'   => '2007-07-26',
             'name'   => 'indent Plugin',
-            'desc'   => 'handles space-bar indenting for gckg',
+            'desc'   => 'handles space-bar indenting for DokuWikiFCK/fckg',
             'url'    => 'http://www.mturner.org/development/',
         );
     }
@@ -37,22 +37,27 @@ class syntax_plugin_fckg_indent extends DokuWiki_Syntax_Plugin {
     function getSort(){ return 190; }
     function connectTo($mode) {
          $this->Lexer->addSpecialPattern('<indent.*?</indent>',$mode,'plugin_fckg_indent'); 
+         $this->Lexer->addSpecialPattern('<br />',$mode,'plugin_fckg_indent');
        }
 
     function handle($match, $state, $pos, &$handler){    
+   
+    if($match == '<br />') return array( $state, $match);  // used in tables
+
     $user_agent = $_SERVER['HTTP_USER_AGENT'];
     if( (isset($_REQUEST['do']) && $_REQUEST['do'] == 'edit') || isset($_REQUEST['do']['edit']) ) {
          $edit = true;
    }
-   else $edit = false;
+   else { $edit = false;  }
 
     if(preg_match('/Firefox/i',$user_agent) && $edit) {
-            $match = preg_replace('/(&#183;){3}/', "\xa0\xa0", $match);
-	        $match = preg_replace('/(\xb7){3}/', "\xa0\xa0", $match);       
+            $match = preg_replace('/(&#183;){2}/', "\xa0\xa0", $match);
+	        $match = preg_replace('/(\xb7){2}/', "\xa0\xa0", $match);       
     }	
-    else { 
+    else {             
          $match = preg_replace('/&#183;/', "&nbsp;", $match);
          $match = preg_replace('/\xb7/', "&nbsp;", $match);
+
     }
  
     if(preg_match('/MSIE/',$user_agent)) { 
@@ -60,8 +65,8 @@ class syntax_plugin_fckg_indent extends DokuWiki_Syntax_Plugin {
     }
     else {   
           if($edit) {
-                 $match = preg_replace('/([\xa1-\xff]){3}/', "\xa0\xa0", $match);  // FireFox needs \xa0
-          }
+                 $match = preg_replace('/([\xa1-\xff]){2}/', "\xa0\xa0", $match);  // FireFox needs \xa0
+           }
           else $match = preg_replace('/[\xa1-\xff]/', "&nbsp;", $match);
     }
 
